# antimatter-api
Interact with the Antimatter Cloud API

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0.15
- Package version: 1.0.15
- Generator version: 7.4.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.7+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import antimatter_api
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import antimatter_api
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import antimatter_api
from antimatter_api.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://api.antimatter.io/v1
# See configuration.py for a list of all supported configuration parameters.
configuration = antimatter_api.Configuration(
    host = "https://api.antimatter.io/v1"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure Bearer authorization (JWT): google_oauth_token
configuration = antimatter_api.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Configure Bearer authorization (JWT): microsoft_oauth_token
configuration = antimatter_api.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)


# Enter a context with an instance of the API client
with antimatter_api.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = antimatter_api.AccountManagementApi(api_client)
    domain_id = 'domain_id_example' # str | 

    try:
        # Adds to starred domains
        api_instance.starred_domain_add(domain_id)
    except ApiException as e:
        print("Exception when calling AccountManagementApi->starred_domain_add: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://api.antimatter.io/v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AccountManagementApi* | [**starred_domain_add**](docs/AccountManagementApi.md#starred_domain_add) | **PUT** /global/starred-domains/{domainID} | Adds to starred domains
*AccountManagementApi* | [**starred_domain_list**](docs/AccountManagementApi.md#starred_domain_list) | **GET** /global/starred-domains | List the user&#39;s starred domains
*AccountManagementApi* | [**starred_domain_remove**](docs/AccountManagementApi.md#starred_domain_remove) | **DELETE** /global/starred-domains/{domainID} | Removes from starred domains
*AuthenticationApi* | [**domain_authenticate**](docs/AuthenticationApi.md#domain_authenticate) | **POST** /domains/{domainID}/authenticate | Authenticate with a domain
*AuthenticationApi* | [**domain_contact_issue_verify**](docs/AuthenticationApi.md#domain_contact_issue_verify) | **POST** /domains/{domainID}/account/verify | Issue a new verification request
*AuthenticationApi* | [**domain_contact_verify**](docs/AuthenticationApi.md#domain_contact_verify) | **GET** /domains/{domainID}/account/verify | Verify an admin contact email
*AuthenticationApi* | [**domain_delete_capability**](docs/AuthenticationApi.md#domain_delete_capability) | **DELETE** /domains/{domainID}/control/capabilities/{capability} | Delete a capability
*AuthenticationApi* | [**domain_delete_identity_provider**](docs/AuthenticationApi.md#domain_delete_identity_provider) | **DELETE** /domains/{domainID}/control/identities/{identityProviderName} | Delete an identity provider
*AuthenticationApi* | [**domain_delete_identity_provider_principal**](docs/AuthenticationApi.md#domain_delete_identity_provider_principal) | **DELETE** /domains/{domainID}/control/identities/{identityProviderName}/principals/{principalID} | Delete identity provider principal
*AuthenticationApi* | [**domain_get_capabilities**](docs/AuthenticationApi.md#domain_get_capabilities) | **GET** /domains/{domainID}/control/capabilities | Get the domain capabilities
*AuthenticationApi* | [**domain_get_capability**](docs/AuthenticationApi.md#domain_get_capability) | **GET** /domains/{domainID}/control/capabilities/{capability} | Get a single capability
*AuthenticationApi* | [**domain_get_identity_provider**](docs/AuthenticationApi.md#domain_get_identity_provider) | **GET** /domains/{domainID}/control/identities/{identityProviderName} | Get an identity provider&#39;s details
*AuthenticationApi* | [**domain_get_identity_provider_principal**](docs/AuthenticationApi.md#domain_get_identity_provider_principal) | **GET** /domains/{domainID}/control/identities/{identityProviderName}/principals/{principalID} | Get identity provider principal details
*AuthenticationApi* | [**domain_get_identity_provider_principals**](docs/AuthenticationApi.md#domain_get_identity_provider_principals) | **GET** /domains/{domainID}/control/identities/{identityProviderName}/principals | Get an identity provider&#39;s principals
*AuthenticationApi* | [**domain_insert_identity_provider_principal**](docs/AuthenticationApi.md#domain_insert_identity_provider_principal) | **POST** /domains/{domainID}/control/identities/{identityProviderName}/principals | Create a new principal for the provider
*AuthenticationApi* | [**domain_list_identity_providers**](docs/AuthenticationApi.md#domain_list_identity_providers) | **GET** /domains/{domainID}/control/identities | Get a summary of the domain&#39;s Identity Providers
*AuthenticationApi* | [**domain_put_capability**](docs/AuthenticationApi.md#domain_put_capability) | **PUT** /domains/{domainID}/control/capabilities/{capability} | Create or update a capability
*AuthenticationApi* | [**domain_update_identity_provider_principal**](docs/AuthenticationApi.md#domain_update_identity_provider_principal) | **PUT** /domains/{domainID}/control/identities/{identityProviderName}/principals/{principalID} | Update identity provider principal capabilities
*AuthenticationApi* | [**domain_upsert_identity_provider**](docs/AuthenticationApi.md#domain_upsert_identity_provider) | **PUT** /domains/{domainID}/control/identities/{identityProviderName} | Create/Update an identity provider
*CapsulesApi* | [**capsule_get_by_id**](docs/CapsulesApi.md#capsule_get_by_id) | **GET** /capsules/{capsuleID} | Get a Capsule by ID
*CapsulesApi* | [**domain_delete_capsule_tags**](docs/CapsulesApi.md#domain_delete_capsule_tags) | **POST** /domains/{domainID}/capsules/{capsuleID}/capsule-tags/delete | Delete capsule-level tags
*CapsulesApi* | [**domain_get_capsule_info**](docs/CapsulesApi.md#domain_get_capsule_info) | **GET** /domains/{domainID}/capsules/{capsuleID} | Get capsule info
*CapsulesApi* | [**domain_get_tag_info**](docs/CapsulesApi.md#domain_get_tag_info) | **GET** /domains/{domainID}/tag-info | Get an ordered list of the top 100 tags.
*CapsulesApi* | [**domain_list_capsules**](docs/CapsulesApi.md#domain_list_capsules) | **GET** /domains/{domainID}/capsules | Get capsule list
*CapsulesApi* | [**domain_query_access_log**](docs/CapsulesApi.md#domain_query_access_log) | **GET** /domains/{domainID}/log | Get the domain data-plane audit log
*CapsulesApi* | [**domain_query_access_log_single_capsule**](docs/CapsulesApi.md#domain_query_access_log_single_capsule) | **GET** /domains/{domainID}/capsules/{capsuleID}/log | Get the access log for a single capsule
*CapsulesApi* | [**domain_upsert_capsule_tags**](docs/CapsulesApi.md#domain_upsert_capsule_tags) | **POST** /domains/{domainID}/capsules/{capsuleID}/capsule-tags | Upsert capsule-scope tags
*ContextsApi* | [**domain_add_read_context_rule**](docs/ContextsApi.md#domain_add_read_context_rule) | **POST** /domains/{domainID}/control/read-context/{contextName}/config | Add a read context configuration rule
*ContextsApi* | [**domain_delete_read_context**](docs/ContextsApi.md#domain_delete_read_context) | **DELETE** /domains/{domainID}/control/read-context/{contextName} | Delete a read context
*ContextsApi* | [**domain_delete_read_context_rule**](docs/ContextsApi.md#domain_delete_read_context_rule) | **DELETE** /domains/{domainID}/control/read-context/{contextName}/config/{ruleID} | Delete a read context configuration rule
*ContextsApi* | [**domain_delete_write_context**](docs/ContextsApi.md#domain_delete_write_context) | **DELETE** /domains/{domainID}/control/write-context/{contextName} | Delete a write context
*ContextsApi* | [**domain_delete_write_context_regex_rule**](docs/ContextsApi.md#domain_delete_write_context_regex_rule) | **DELETE** /domains/{domainID}/control/write-context/{contextName}/regex-rule/{ruleID} | 
*ContextsApi* | [**domain_describe_write_context**](docs/ContextsApi.md#domain_describe_write_context) | **GET** /domains/{domainID}/control/write-context/{contextName} | Describe a write context
*ContextsApi* | [**domain_get_read_context**](docs/ContextsApi.md#domain_get_read_context) | **GET** /domains/{domainID}/control/read-context/{contextName} | Get a read context
*ContextsApi* | [**domain_get_write_context_regex_rules**](docs/ContextsApi.md#domain_get_write_context_regex_rules) | **GET** /domains/{domainID}/control/write-context/{contextName}/regex-rule | 
*ContextsApi* | [**domain_insert_write_context_regex_rule**](docs/ContextsApi.md#domain_insert_write_context_regex_rule) | **POST** /domains/{domainID}/control/write-context/{contextName}/regex-rule | Insert a write context regex rule
*ContextsApi* | [**domain_list_hooks**](docs/ContextsApi.md#domain_list_hooks) | **GET** /domains/{domainID}/hooks | Lists available hooks
*ContextsApi* | [**domain_list_read_contexts**](docs/ContextsApi.md#domain_list_read_contexts) | **GET** /domains/{domainID}/control/read-context | List domain read contexts
*ContextsApi* | [**domain_list_write_contexts**](docs/ContextsApi.md#domain_list_write_contexts) | **GET** /domains/{domainID}/control/write-context | List domain write contexts
*ContextsApi* | [**domain_read_context_flush**](docs/ContextsApi.md#domain_read_context_flush) | **POST** /domains/{domainID}/control/read-context/{contextName}/flush | Flush the read context cache
*ContextsApi* | [**domain_update_read_context_rule**](docs/ContextsApi.md#domain_update_read_context_rule) | **PUT** /domains/{domainID}/control/read-context/{contextName}/config/{ruleID} | Update a read context configuration rule
*ContextsApi* | [**domain_upsert_read_context**](docs/ContextsApi.md#domain_upsert_read_context) | **PUT** /domains/{domainID}/control/read-context/{contextName} | Update or create a read context
*ContextsApi* | [**domain_upsert_write_context**](docs/ContextsApi.md#domain_upsert_write_context) | **PUT** /domains/{domainID}/control/write-context/{contextName} | Upsert a write context
*ContextsApi* | [**domain_upsert_write_context_configuration**](docs/ContextsApi.md#domain_upsert_write_context_configuration) | **PUT** /domains/{domainID}/control/write-context/{contextName}/config | Update a write context configuration
*EncryptionApi* | [**domain_add_external_root_encryption_key**](docs/EncryptionApi.md#domain_add_external_root_encryption_key) | **POST** /domains/{domainID}/control/keys | Add a new external root encryption key.
*EncryptionApi* | [**domain_delete_external_root_encryption_key**](docs/EncryptionApi.md#domain_delete_external_root_encryption_key) | **DELETE** /domains/{domainID}/control/keys/{rootEncryptionKeyID} | Delete an external root encryption key by ID.
*EncryptionApi* | [**domain_external_root_encryption_key_test**](docs/EncryptionApi.md#domain_external_root_encryption_key_test) | **POST** /domains/{domainID}/control/keys/{rootEncryptionKeyID}/test | Test the health of a root encryption key
*EncryptionApi* | [**domain_flush_encryption_keys**](docs/EncryptionApi.md#domain_flush_encryption_keys) | **POST** /domains/{domainID}/encryption/flush | Flush all encryption keys
*EncryptionApi* | [**domain_get_active_external_root_encryption_key**](docs/EncryptionApi.md#domain_get_active_external_root_encryption_key) | **GET** /domains/{domainID}/control/keys/active | Get the active root encryption key&#39;s information.
*EncryptionApi* | [**domain_get_external_root_encryption_key_providers**](docs/EncryptionApi.md#domain_get_external_root_encryption_key_providers) | **GET** /domains/{domainID}/control/keys/providers | Returns a list of available root encryption key providers.
*EncryptionApi* | [**domain_list_external_root_encryption_key**](docs/EncryptionApi.md#domain_list_external_root_encryption_key) | **GET** /domains/{domainID}/control/keys | List all external root encryption keys.
*EncryptionApi* | [**domain_rotate_root_encryption_keys**](docs/EncryptionApi.md#domain_rotate_root_encryption_keys) | **POST** /domains/{domainID}/control/keys/rotate | Re-encrypt key encryption keys.
*EncryptionApi* | [**domain_set_active_external_root_encryption_key**](docs/EncryptionApi.md#domain_set_active_external_root_encryption_key) | **POST** /domains/{domainID}/control/keys/active | Set the active root encryption key
*GeneralApi* | [**domain_add_new**](docs/GeneralApi.md#domain_add_new) | **POST** /domains | Add a new domain
*GeneralApi* | [**domain_create_peer_domain**](docs/GeneralApi.md#domain_create_peer_domain) | **POST** /domains/{domainID}/peer-domain | Create a peer domain
*GeneralApi* | [**domain_delete_peer**](docs/GeneralApi.md#domain_delete_peer) | **DELETE** /domains/{domainID}/control/peers/{peerDomainID} | Delete a peer domain
*GeneralApi* | [**domain_get_peer**](docs/GeneralApi.md#domain_get_peer) | **GET** /domains/{domainID}/peer-domain | Get a peer domain by nickname or alias
*GeneralApi* | [**domain_get_peer_config**](docs/GeneralApi.md#domain_get_peer_config) | **GET** /domains/{domainID}/control/peers/{peerDomainID} | Get peer configuration
*GeneralApi* | [**domain_get_private_info**](docs/GeneralApi.md#domain_get_private_info) | **GET** /domains/{domainID}/info | Get the summary info for a Domain
*GeneralApi* | [**domain_get_public_info**](docs/GeneralApi.md#domain_get_public_info) | **GET** /domains/{domainID}/public-info | Get the public info for a Domain
*GeneralApi* | [**domain_get_settings**](docs/GeneralApi.md#domain_get_settings) | **GET** /domains/{domainID}/control/settings | Get the domain settings
*GeneralApi* | [**domain_get_status**](docs/GeneralApi.md#domain_get_status) | **GET** /domains/{domainID}/control/status | Get the domain status
*GeneralApi* | [**domain_list_peers**](docs/GeneralApi.md#domain_list_peers) | **GET** /domains/{domainID}/control/peers | List domain peers
*GeneralApi* | [**domain_patch_settings**](docs/GeneralApi.md#domain_patch_settings) | **PATCH** /domains/{domainID}/control/settings | Update the domain settings
*GeneralApi* | [**domain_query_control_log**](docs/GeneralApi.md#domain_query_control_log) | **GET** /domains/{domainID}/control/log | Get the domain control-plane audit log
*GeneralApi* | [**domain_update_peer**](docs/GeneralApi.md#domain_update_peer) | **PUT** /domains/{domainID}/control/peers/{peerDomainID} | Update peer configuration
*InternalApi* | [**domain_add_access_log_entry**](docs/InternalApi.md#domain_add_access_log_entry) | **POST** /domains/{domainID}/capsules/{capsuleID}/log | Add a capsule audit log entry
*InternalApi* | [**domain_create_capsule**](docs/InternalApi.md#domain_create_capsule) | **POST** /domains/{domainID}/capsules | Create a capsule
*InternalApi* | [**domain_data_tagging_hook_invoke**](docs/InternalApi.md#domain_data_tagging_hook_invoke) | **POST** /domains/{domainID}/hooks/data-tagging/{hookName}/invoke | Invoke a hook
*InternalApi* | [**domain_open_capsule**](docs/InternalApi.md#domain_open_capsule) | **POST** /domains/{domainID}/capsules/{capsuleID}/open | Open a capsule for reading
*InternalApi* | [**domain_seal_capsule**](docs/InternalApi.md#domain_seal_capsule) | **POST** /domains/{domainID}/capsules/{capsuleID}/seal | Seal a capsule
*InternalApi* | [**domain_upsert_span_tags**](docs/InternalApi.md#domain_upsert_span_tags) | **PUT** /domains/{domainID}/capsules/{capsuleID}/span-tags | Upsert span-scope tags
*PolicyApi* | [**domain_create_policy_rule**](docs/PolicyApi.md#domain_create_policy_rule) | **POST** /domains/{domainID}/control/policy | Create a domain policy rule
*PolicyApi* | [**domain_delete_fact_by_id**](docs/PolicyApi.md#domain_delete_fact_by_id) | **DELETE** /domains/{domainID}/control/facts/{factType}/{factID} | Delete a fact
*PolicyApi* | [**domain_delete_fact_type**](docs/PolicyApi.md#domain_delete_fact_type) | **DELETE** /domains/{domainID}/control/facts/{factType} | Delete a fact type
*PolicyApi* | [**domain_delete_policy_rule**](docs/PolicyApi.md#domain_delete_policy_rule) | **DELETE** /domains/{domainID}/control/policy/{ruleID} | Delete a domain policy rule
*PolicyApi* | [**domain_get_fact_by_id**](docs/PolicyApi.md#domain_get_fact_by_id) | **GET** /domains/{domainID}/control/facts/{factType}/{factID} | Get a fact by ID
*PolicyApi* | [**domain_get_fact_type**](docs/PolicyApi.md#domain_get_fact_type) | **GET** /domains/{domainID}/control/facts/{factType} | Get a fact type definition
*PolicyApi* | [**domain_list_fact_types**](docs/PolicyApi.md#domain_list_fact_types) | **GET** /domains/{domainID}/control/facts | List the domain&#39;s fact types
*PolicyApi* | [**domain_list_facts**](docs/PolicyApi.md#domain_list_facts) | **GET** /domains/{domainID}/control/facts/{factType}/list | Get facts for a type
*PolicyApi* | [**domain_list_policy_rules**](docs/PolicyApi.md#domain_list_policy_rules) | **GET** /domains/{domainID}/control/policy | Get the domain policy rules
*PolicyApi* | [**domain_list_resources**](docs/PolicyApi.md#domain_list_resources) | **GET** /domains/{domainID}/control/resources | Get a summary of access control resource paths
*PolicyApi* | [**domain_policy_flush**](docs/PolicyApi.md#domain_policy_flush) | **POST** /domains/{domainID}/control/policy/flush | Flush the policy cache
*PolicyApi* | [**domain_put_fact_type**](docs/PolicyApi.md#domain_put_fact_type) | **PUT** /domains/{domainID}/control/facts/{factType} | Create a fact type
*PolicyApi* | [**domain_renumber_policy_rules**](docs/PolicyApi.md#domain_renumber_policy_rules) | **POST** /domains/{domainID}/control/policy/renumber | Re-assign rule numbers
*PolicyApi* | [**domain_update_policy_rule**](docs/PolicyApi.md#domain_update_policy_rule) | **PUT** /domains/{domainID}/control/policy/{ruleID} | Update a domain policy rule
*PolicyApi* | [**domain_upsert_fact**](docs/PolicyApi.md#domain_upsert_fact) | **POST** /domains/{domainID}/control/facts/{factType}/new | Upsert a fact


## Documentation For Models

 - [APIKeyDomainIdentityProviderDetails](docs/APIKeyDomainIdentityProviderDetails.md)
 - [AWSServiceAccountKeyInfo](docs/AWSServiceAccountKeyInfo.md)
 - [AccessLogEntry](docs/AccessLogEntry.md)
 - [AccessLogEntryCreateInfo](docs/AccessLogEntryCreateInfo.md)
 - [AccessLogEntryOpenInfo](docs/AccessLogEntryOpenInfo.md)
 - [AccessLogEntryReadInfo](docs/AccessLogEntryReadInfo.md)
 - [AccessLogResults](docs/AccessLogResults.md)
 - [ActiveRootEncryptionKeyID](docs/ActiveRootEncryptionKeyID.md)
 - [AddCapsuleLogEntryRequest](docs/AddCapsuleLogEntryRequest.md)
 - [AddReadContext](docs/AddReadContext.md)
 - [AddWriteContext](docs/AddWriteContext.md)
 - [AntimatterDelegatedAWSKeyInfo](docs/AntimatterDelegatedAWSKeyInfo.md)
 - [AvailableDelegatedRootEncryptionKeyProvider](docs/AvailableDelegatedRootEncryptionKeyProvider.md)
 - [AvailableRootEncryptionKeyProviders](docs/AvailableRootEncryptionKeyProviders.md)
 - [AvailableRootEncryptionKeyProvidersProvidersInner](docs/AvailableRootEncryptionKeyProvidersProvidersInner.md)
 - [AvailableServiceAccountRootEncryptionKeyProvider](docs/AvailableServiceAccountRootEncryptionKeyProvider.md)
 - [Capability](docs/Capability.md)
 - [CapabilityDefinition](docs/CapabilityDefinition.md)
 - [CapabilityDefinitionList](docs/CapabilityDefinitionList.md)
 - [CapabilityList](docs/CapabilityList.md)
 - [CapabilityRule](docs/CapabilityRule.md)
 - [CapabilityRuleMatchExpressionsInner](docs/CapabilityRuleMatchExpressionsInner.md)
 - [CapsuleCreateResponse](docs/CapsuleCreateResponse.md)
 - [CapsuleInfo](docs/CapsuleInfo.md)
 - [CapsuleList](docs/CapsuleList.md)
 - [CapsuleOpenRequest](docs/CapsuleOpenRequest.md)
 - [CapsuleOpenResponse](docs/CapsuleOpenResponse.md)
 - [CapsuleOpenResponseReadContextConfiguration](docs/CapsuleOpenResponseReadContextConfiguration.md)
 - [CapsuleSealRequest](docs/CapsuleSealRequest.md)
 - [ConflictError](docs/ConflictError.md)
 - [CreatePeerDomain](docs/CreatePeerDomain.md)
 - [DataTaggingHookInput](docs/DataTaggingHookInput.md)
 - [DataTaggingHookInputRecordsInner](docs/DataTaggingHookInputRecordsInner.md)
 - [DataTaggingHookInputRecordsInnerElementsInner](docs/DataTaggingHookInputRecordsInnerElementsInner.md)
 - [DataTaggingHookResponse](docs/DataTaggingHookResponse.md)
 - [DataTaggingHookResponseRecordsInner](docs/DataTaggingHookResponseRecordsInner.md)
 - [DeleteTags](docs/DeleteTags.md)
 - [Domain](docs/Domain.md)
 - [DomainAddReadContextRule200Response](docs/DomainAddReadContextRule200Response.md)
 - [DomainAuthenticate](docs/DomainAuthenticate.md)
 - [DomainAuthenticateResponse](docs/DomainAuthenticateResponse.md)
 - [DomainContactIssueVerifyRequest](docs/DomainContactIssueVerifyRequest.md)
 - [DomainControlLogEntry](docs/DomainControlLogEntry.md)
 - [DomainControlLogResults](docs/DomainControlLogResults.md)
 - [DomainFactList](docs/DomainFactList.md)
 - [DomainHooksList](docs/DomainHooksList.md)
 - [DomainHooksListHooksInner](docs/DomainHooksListHooksInner.md)
 - [DomainIdentityAPIKeyPrincipalParams](docs/DomainIdentityAPIKeyPrincipalParams.md)
 - [DomainIdentityEmailPrincipalParams](docs/DomainIdentityEmailPrincipalParams.md)
 - [DomainIdentityHostedDomainPrincipalParams](docs/DomainIdentityHostedDomainPrincipalParams.md)
 - [DomainIdentityPrincipalDetails](docs/DomainIdentityPrincipalDetails.md)
 - [DomainIdentityProviderDetails](docs/DomainIdentityProviderDetails.md)
 - [DomainIdentityProviderInfo](docs/DomainIdentityProviderInfo.md)
 - [DomainIdentityProviderList](docs/DomainIdentityProviderList.md)
 - [DomainIdentityProviderPrincipalList](docs/DomainIdentityProviderPrincipalList.md)
 - [DomainIdentityProviderPrincipalParams](docs/DomainIdentityProviderPrincipalParams.md)
 - [DomainIdentityProviderPrincipalType](docs/DomainIdentityProviderPrincipalType.md)
 - [DomainIdentityProviderType](docs/DomainIdentityProviderType.md)
 - [DomainInsertIdentityProviderPrincipal200Response](docs/DomainInsertIdentityProviderPrincipal200Response.md)
 - [DomainInsertWriteContextRegexRule200Response](docs/DomainInsertWriteContextRegexRule200Response.md)
 - [DomainPeerConfig](docs/DomainPeerConfig.md)
 - [DomainPeerList](docs/DomainPeerList.md)
 - [DomainPeerListPeersInner](docs/DomainPeerListPeersInner.md)
 - [DomainPolicy](docs/DomainPolicy.md)
 - [DomainPolicyRule](docs/DomainPolicyRule.md)
 - [DomainPrivateInfo](docs/DomainPrivateInfo.md)
 - [DomainPublicInfo](docs/DomainPublicInfo.md)
 - [DomainResourceSummary](docs/DomainResourceSummary.md)
 - [DomainResourceSummarySchemaInner](docs/DomainResourceSummarySchemaInner.md)
 - [DomainSettings](docs/DomainSettings.md)
 - [DomainSettingsDisasterRecovery](docs/DomainSettingsDisasterRecovery.md)
 - [DomainSettingsPatch](docs/DomainSettingsPatch.md)
 - [DomainStatus](docs/DomainStatus.md)
 - [DomainStatusNotificationsInner](docs/DomainStatusNotificationsInner.md)
 - [DomainTagInfoResults](docs/DomainTagInfoResults.md)
 - [Error](docs/Error.md)
 - [Fact](docs/Fact.md)
 - [FactList](docs/FactList.md)
 - [FactPolicyRulesInner](docs/FactPolicyRulesInner.md)
 - [FactPolicyRulesInnerArgumentsInner](docs/FactPolicyRulesInnerArgumentsInner.md)
 - [FactTypeDefinition](docs/FactTypeDefinition.md)
 - [ForbiddenError](docs/ForbiddenError.md)
 - [GCPServiceAccountKeyInfo](docs/GCPServiceAccountKeyInfo.md)
 - [GoogleOAuthDomainIdentityProviderDetails](docs/GoogleOAuthDomainIdentityProviderDetails.md)
 - [HookInvocation](docs/HookInvocation.md)
 - [InvalidRequestError](docs/InvalidRequestError.md)
 - [JSONPatchRequestAdd](docs/JSONPatchRequestAdd.md)
 - [JSONPatchRequestAddValue](docs/JSONPatchRequestAddValue.md)
 - [JSONPatchRequestCopy](docs/JSONPatchRequestCopy.md)
 - [JSONPatchRequestMove](docs/JSONPatchRequestMove.md)
 - [JSONPatchRequestRemove](docs/JSONPatchRequestRemove.md)
 - [JSONPatchRequestReplace](docs/JSONPatchRequestReplace.md)
 - [JSONPatchRequestReplaceValue](docs/JSONPatchRequestReplaceValue.md)
 - [JSONPatchRequestTst](docs/JSONPatchRequestTst.md)
 - [JSONPatchRequestTstValue](docs/JSONPatchRequestTstValue.md)
 - [KeyInfos](docs/KeyInfos.md)
 - [KeyInfosKeyInformation](docs/KeyInfosKeyInformation.md)
 - [NewAccessLogEntry](docs/NewAccessLogEntry.md)
 - [NewAccessLogEntryReadInfo](docs/NewAccessLogEntryReadInfo.md)
 - [NewCapabilityDefinition](docs/NewCapabilityDefinition.md)
 - [NewDomain](docs/NewDomain.md)
 - [NewDomainPolicyRule](docs/NewDomainPolicyRule.md)
 - [NewDomainResponse](docs/NewDomainResponse.md)
 - [NewFact](docs/NewFact.md)
 - [NewFactTypeDefinition](docs/NewFactTypeDefinition.md)
 - [NewFactTypeDefinitionArgumentsInner](docs/NewFactTypeDefinitionArgumentsInner.md)
 - [NewReadContextConfigRule](docs/NewReadContextConfigRule.md)
 - [PatchRequestInner](docs/PatchRequestInner.md)
 - [PolicyRuleOperation](docs/PolicyRuleOperation.md)
 - [PolicyRuleResult](docs/PolicyRuleResult.md)
 - [PrincipalInfo](docs/PrincipalInfo.md)
 - [PrincipalSummary](docs/PrincipalSummary.md)
 - [ReadContextConfigRule](docs/ReadContextConfigRule.md)
 - [ReadContextDetails](docs/ReadContextDetails.md)
 - [ReadContextList](docs/ReadContextList.md)
 - [ReadContextParameter](docs/ReadContextParameter.md)
 - [ReadContextRequiredHook](docs/ReadContextRequiredHook.md)
 - [ReadContextRuleFactsInner](docs/ReadContextRuleFactsInner.md)
 - [ReadContextRuleFactsInnerArgumentsInner](docs/ReadContextRuleFactsInnerArgumentsInner.md)
 - [ReadContextRuleMatchExpressionsInner](docs/ReadContextRuleMatchExpressionsInner.md)
 - [ReadContextShortDetails](docs/ReadContextShortDetails.md)
 - [ResourceExhaustedError](docs/ResourceExhaustedError.md)
 - [ResourceNotFoundError](docs/ResourceNotFoundError.md)
 - [RootEncryptionKeyIDResponse](docs/RootEncryptionKeyIDResponse.md)
 - [RootEncryptionKeyItem](docs/RootEncryptionKeyItem.md)
 - [RootEncryptionKeyTestResponse](docs/RootEncryptionKeyTestResponse.md)
 - [RotateKeyEncryptionKeyResponse](docs/RotateKeyEncryptionKeyResponse.md)
 - [StarredDomainList](docs/StarredDomainList.md)
 - [Tag](docs/Tag.md)
 - [TagMeta](docs/TagMeta.md)
 - [TagSet](docs/TagSet.md)
 - [TagSetSpanTagsInner](docs/TagSetSpanTagsInner.md)
 - [TagSummary](docs/TagSummary.md)
 - [TagSummaryElidedTagsInner](docs/TagSummaryElidedTagsInner.md)
 - [TagSummaryUniqueTagsInner](docs/TagSummaryUniqueTagsInner.md)
 - [TagTypeField](docs/TagTypeField.md)
 - [UnauthorizedError](docs/UnauthorizedError.md)
 - [UpsertSpanTagsRequest](docs/UpsertSpanTagsRequest.md)
 - [VerifyContactResponse](docs/VerifyContactResponse.md)
 - [WriteContextConfigInfo](docs/WriteContextConfigInfo.md)
 - [WriteContextConfigInfoRequiredHooksInner](docs/WriteContextConfigInfoRequiredHooksInner.md)
 - [WriteContextDetails](docs/WriteContextDetails.md)
 - [WriteContextList](docs/WriteContextList.md)
 - [WriteContextRegexRule](docs/WriteContextRegexRule.md)
 - [WriteContextRegexTag](docs/WriteContextRegexTag.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="domain_identity"></a>
### domain_identity

- **Type**: Bearer authentication (JWT)

<a id="google_oauth_token"></a>
### google_oauth_token

- **Type**: Bearer authentication (JWT)

<a id="microsoft_oauth_token"></a>
### microsoft_oauth_token

- **Type**: Bearer authentication (JWT)


## Author

support@antimatter.io


